==> qt-creator-opensource-src-3.5.1.tar.gz: qt-creator-opensource-src-3.5.1/src/plugins/qmlprojectmanager/qmlprojectenvironmentaspect.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "qmlprojectenvironmentaspect.h"

#include <utils/qtcassert.h>

namespace QmlProjectManager {

// --------------------------------------------------------------------
// QmlProjectEnvironmentAspect:
// --------------------------------------------------------------------

QList<int> QmlProjectEnvironmentAspect::possibleBaseEnvironments() const
{
    return QList<int>() << static_cast<int>(SystemEnvironmentBase);
}

QString QmlProjectEnvironmentAspect::baseEnvironmentDisplayName(int base) const
{
    if (base == static_cast<int>(SystemEnvironmentBase))
        return tr("System Environment");
    return QString();
}

Utils::Environment QmlProjectManager::QmlProjectEnvironmentAspect::baseEnvironment() const
{
    return Utils::Environment::systemEnvironment();
}

QmlProjectEnvironmentAspect::QmlProjectEnvironmentAspect(ProjectExplorer::RunConfiguration *rc) :
    ProjectExplorer::EnvironmentAspect(rc)
{ }

QmlProjectEnvironmentAspect *QmlProjectEnvironmentAspect::create(ProjectExplorer::RunConfiguration *parent) const
{
    return new QmlProjectEnvironmentAspect(parent);
}

} // namespace QmlProjectManager

==> qt-creator-opensource-src-3.6.1.tar.gz: qt-creator-opensource-src-3.6.1/src/plugins/qmlprojectmanager/qmlprojectenvironmentaspect.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "qmlprojectenvironmentaspect.h"

#include <projectexplorer/target.h>
#include <projectexplorer/kit.h>
#include <utils/qtcassert.h>

namespace QmlProjectManager {

// --------------------------------------------------------------------
// QmlProjectEnvironmentAspect:
// --------------------------------------------------------------------

QList<int> QmlProjectEnvironmentAspect::possibleBaseEnvironments() const
{
    return QList<int>() << static_cast<int>(KitEnvironmentBase)
                        << static_cast<int>(SystemEnvironmentBase);
}

QString QmlProjectEnvironmentAspect::baseEnvironmentDisplayName(int base) const
{
    if (base == static_cast<int>(SystemEnvironmentBase))
        return tr("System Environment");
    if (base == static_cast<int>(KitEnvironmentBase))
        return tr("Kit Environment");
    return QString();
}

Utils::Environment QmlProjectEnvironmentAspect::baseEnvironment() const
{
    int base = baseEnvironmentBase();
    Utils::Environment env = Utils::Environment::systemEnvironment();
    if (base == static_cast<int>(KitEnvironmentBase))
        runConfiguration()->target()->kit()->addToEnvironment(env);

    return env;
}

QmlProjectEnvironmentAspect::QmlProjectEnvironmentAspect(ProjectExplorer::RunConfiguration *rc) :
    ProjectExplorer::EnvironmentAspect(rc)
{ }

QmlProjectEnvironmentAspect *QmlProjectEnvironmentAspect::create(ProjectExplorer::RunConfiguration *parent) const
{
    return new QmlProjectEnvironmentAspect(parent);
}

} // namespace QmlProjectManager
